==> echobase-ui-2.4-sources.jar: fr/ifremer/echobase/ui/actions/dbeditor/LoadEntities.java <==
/*
 * #%L
 * EchoBase :: UI
 * 
 * $Id: LoadEntities.java 143 2011-12-05 08:27:35Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.4/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/dbeditor/LoadEntities.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.echobase.ui.actions.dbeditor;

/**
 * To load the db editor pages.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.1
 */
public class LoadEntities extends AbstractLoadPage {

    private static final long serialVersionUID = 1L;

    /** Default name of the export file. */
    protected String exportFileName;

    public String getExportFileName() {
        return exportFileName;
    }

    @Override
    public String input() throws Exception {

        load();
        if (tableMeta != null) {
            exportFileName = "export-" + tableMeta.getEntityType().getSimpleName() + ".csv";
        }
        return INPUT;
    }
}

==> echobase-ui-2.5-sources.jar: fr/ifremer/echobase/ui/actions/dbeditor/LoadEntities.java <==
/*
 * #%L
 * EchoBase :: UI
 * 
 * $Id: LoadEntities.java 892 2013-11-22 07:01:59Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.5/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/dbeditor/LoadEntities.java $
 * %%
 * Copyright (C) 2011 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.echobase.ui.actions.dbeditor;

/**
 * To load the db editor pages.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.1
 */
public class LoadEntities extends AbstractLoadPage {

    private static final long serialVersionUID = 1L;

    /** Default name of the export file. */
    protected String exportFileName;

    public String getExportFileName() {
        return exportFileName;
    }

    @Override
    public String execute() throws Exception {

        load();
        if (tableMeta != null) {
            exportFileName = "export-" + tableMeta.getEntityType().getSimpleName() + ".csv";
        }
        return SUCCESS;
    }

    public boolean isAdmin() {
        return getEchoBaseSession().isAdmin();
    }
}
